@@ -5,7 +5,7 @@ color.factor<-function(color, value, max){
     dim(t.rgb)<-c(3,l.color*length(value))
     value[is.na(value)]<-0
     t.rgb<-255-((255-t.rgb)*rep(value, each=3)/max)
-    return(rgb(red=t.rgb[1,], green=t.rgb[2,], blue=t.rgb[3,], max=255))
+    return(rgb(red=t.rgb[1,], green=t.rgb[2,], blue=t.rgb[3,], maxColorValue=255))
 
 }
 
